@@ -11,14 +11,14 @@ from typing import Optional
 # pip dependency
 from termcolor import cprint
 # local
-from . import get_version_string
-from .config import load_config, sanitize_config
+from . import get_version_string, print_error
+from .config import load_config, sanitize_config, SclConfig
 
 EXTENSIONS = [".json", ".log", ".time"]
 FZF_PATH = "fzf"
 
 
-def replay_command(output_file: str) -> int:
+def replay_command(output_file: str, scl_config: SclConfig) -> int:
     metadata = parse_metadata(f"{output_file}.json")
     
     metadata and print_header(metadata)
@@ -27,7 +27,7 @@ def replay_command(output_file: str) -> int:
         "scriptreplay",
         "--log-out", f"{output_file}.log", # read the output file
         "--log-timing", f"{output_file}.time", # also read the timing file
-        # @TODO: --divisor <num>     speed up or slow down execution with time divisor
+        "--divisor", str(scl_config.replay_speed),# @TODO why does this finish immediately with values > 1?
     ]
 
     try:
@@ -44,9 +44,9 @@ def parse_metadata(path: str) -> Optional[dict]:
         with open(path) as f:
             return json.load(f)
     except FileNotFoundError:
-        cprint(f"[scl] Metadata file does not exist: '{path}'", "red", attrs=["bold"])
+        print_error(f"Metadata file does not exist: '{path}'")
     except Exception as e:
-        cprint(f"[scl] Internal error while parsing the metadata in '{path}'", "red", attrs=["bold"])
+        print_error(f"Internal error while parsing the metadata in '{path}'", print_stacktrace=True)
         traceback.print_exc()
     return None
 
@@ -91,12 +91,14 @@ def main_replay(arguments: list[str]) -> int:
     ap.add_argument("-v", "--version", action="version", version=get_version_string())
     args = ap.parse_args(arguments)
 
+    scl_config = sanitize_config(load_config())
+
     if args.input:
         path = args.input
     elif args.select_file:
-        path = select_file()
+        path = select_file(scl_config)
     elif args.select_command:
-        path = select_command()
+        path = select_command(scl_config)
     else:
         raise Exception("Bug: Unreachable code")
 
@@ -106,14 +108,12 @@ def main_replay(arguments: list[str]) -> int:
         path = remove_extension(path)
 
         # replaay the command
-        return replay_command(path)
+        return replay_command(path, scl_config)
     else:
         return 1
 
 
-def select_file() -> Optional[str]:
-    scl_config = sanitize_config(load_config())
-
+def select_file(scl_config: SclConfig) -> Optional[str]:
     log_files = glob.glob("**/*.log", root_dir=scl_config.output_dir, recursive=True)
     if not log_files:
         cprint("No command log files found!", "red")
@@ -140,9 +140,7 @@ def select_file() -> Optional[str]:
             return
 
 
-def select_command() -> Optional[str]:
-    scl_config = sanitize_config(load_config())
-
+def select_command(scl_config: SclConfig) -> Optional[str]:
     log_files = glob.glob("**/*.json", root_dir=scl_config.output_dir, recursive=True)
     if not log_files:
         cprint("No command log files found!", "red")
@@ -153,7 +151,8 @@ def select_command() -> Optional[str]:
         return os.path.join(scl_config.output_dir, only_choice)
     else:
         log_files = [os.path.join(scl_config.output_dir, x) for x in sorted(log_files)]
-        log_file_labels = [format_command(x).strip() for x in log_files]
+        log_file_labels = [CommandFormater(x).format_command(scl_config.command_format).strip()
+                            for x in log_files]
         # use fzf to let the user select the file
         log_files_text = "\n".join(sorted(log_file_labels))
         # Pass choices via stdin, read result from stdout, pass through stderr to show the menu
@@ -171,25 +170,49 @@ def select_command() -> Optional[str]:
             cprint(f"[ERROR] fzf failed with code {process_result.returncode}", "red")
             return
 
+class CommandFormater:
+    def __init__(self, metadata_file: str) -> None:
+        with open(metadata_file, "r") as f:
+            self.metadata = json.load(f)
 
-def format_command(metadata_file: str) -> str:
-    with open(metadata_file, "r") as f:
-        metadata = json.load(f)
+    def get_time(self, name: str) -> str:
+        time = self.metadata.get(name, "<unknown time>")
+        # Remove time zone
+        time = time.split("+")[0]
+        # convert Z to space to visually separate the date from the time
+        time = time.replace("Z", " ")
+        return time
 
-    start_time = metadata.get("start_time", "unknown time")
-    # Remove time zone
-    start_time = start_time.split("+")[0]
-    # convert Z to space to visually separate the date from the time
-    start_time = start_time.replace("Z", " ")
+    def get_statuscode_and_success(self) -> tuple[str, str]:
+        status_code = self.metadata.get("status_code")
+        status_code = "N/A" if status_code == -1 else str(status_code)
+        # checkmark if success else cross
+        success = "✔" if status_code == "0" else "✖"
+        return (status_code, success)
 
-    command = metadata.get("command", ["unknown command"])
-    command = shlex.join(command)
+    def get_command(self) -> str:
+        command = self.metadata.get("command")
+        return shlex.join(command) if command is not None else "<unknown command>"
 
-    status_code = metadata.get("status_code", 0)
-    # checkmark if success else cross
-    success = "✔" if status_code == 0 else "✖"
-
-    return f"[{start_time} | {success} ] {command}"
+    def format_command(self, command_format: str) -> str:
+        command = self.get_command()
+        end_time = self.get_time("end_time")
+        hostname = self.metadata.get("hostname", "<unknown hostname>")
+        start_time = self.get_time("start_time")
+        status_code, success = self.get_statuscode_and_success()
+        username = self.metadata.get("user", "<unknown user>")
+        try:
+            return command_format.format(
+                command=command,
+                end_time=end_time,
+                hostname=hostname,
+                start_time=start_time,
+                status_code=status_code,
+                success=success,
+                username=username,
+            )
+        except KeyError as e:
+            print_error(f"The variable {e} is not a valid placeholder for the command format", raise_error=True)
 
 
 if __name__ == "__main__":
